@@ -6,8 +6,11 @@ import zipfile
 import io
 
 def unpack_sources_from_token(token_file, destination=None):
-    with open(token_file, 'rb') as f:
-        rs = pickle.load(f)
+    # with open(token_file, 'rb') as f:
+    #     rs = pickle.load(f)
+    from unitgrade_private import load_token
+
+    data, _ = load_token(token_file)
     if destination is None:
         destination = os.path.dirname(token_file )
     destination = os.path.normpath(destination)
